summaryrefslogtreecommitdiff
path: root/.gitlab-ci
diff options
context:
space:
mode:
authorDavid Heidelberg <david.heidelberg@collabora.com>2023-03-04 18:01:49 +0100
committerMarge Bot <emma+marge@anholt.net>2023-03-09 21:06:16 +0000
commit505218503937bed2d66e0b9d56e10bec38646f80 (patch)
treed5d4d0ba56e9cd1ec145bb5a25140a0afead0340 /.gitlab-ci
parent675f757ffb6307ff463230bf00b4e2e9219467fc (diff)
downloadmesa-505218503937bed2d66e0b9d56e10bec38646f80.tar.gz
mesa-505218503937bed2d66e0b9d56e10bec38646f80.tar.bz2
mesa-505218503937bed2d66e0b9d56e10bec38646f80.zip
ci/weston: before testing, verify that XWayland is really running
When Xorg already running, Weston XWayland should pick DISPLAY=:1 Reviewed-by: Erico Nunes <nunes.erico@gmail.com> Reviewed-by: Daniel Stone <daniels@collabora.com> Signed-off-by: David Heidelberg <david.heidelberg@collabora.com> Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/21711>
Diffstat (limited to '.gitlab-ci')
-rwxr-xr-x.gitlab-ci/common/init-stage2.sh14
1 files changed, 10 insertions, 4 deletions
diff --git a/.gitlab-ci/common/init-stage2.sh b/.gitlab-ci/common/init-stage2.sh
index a19d47960e0..cb00bedb0c5 100755
--- a/.gitlab-ci/common/init-stage2.sh
+++ b/.gitlab-ci/common/init-stage2.sh
@@ -145,18 +145,24 @@ if [ -n "$HWCI_START_XORG" ]; then
fi
if [ -n "$HWCI_START_WESTON" ]; then
+ WESTON_X11_SOCK="/tmp/.X11-unix/X0"
+ if [ -n "$HWCI_START_XORG" ]; then
+ echo "Please consider dropping HWCI_START_XORG and instead using Weston XWayland for testing."
+ WESTON_X11_SOCK="/tmp/.X11-unix/X1"
+ fi
export XDG_RUNTIME_DIR=/run/user
mkdir -p $XDG_RUNTIME_DIR
+ export WAYLAND_DISPLAY=wayland-0
- # Xwayland to be used when HWCI_START_XORG is not set
+ # Display server is Weston Xwayland when HWCI_START_XORG is not set or Xorg when it's
export DISPLAY=:0
mkdir -p /tmp/.X11-unix
env \
- VK_ICD_FILENAMES=/install/share/vulkan/icd.d/${VK_DRIVER}_icd.`uname -m`.json \
+ VK_ICD_FILENAMES="/install/share/vulkan/icd.d/${VK_DRIVER}_icd.$(uname -m).json" \
weston -Bheadless-backend.so --use-gl -Swayland-0 --xwayland &
- export WAYLAND_DISPLAY=wayland-0
- sleep 1
+
+ while [ ! -S "$WESTON_X11_SOCK" ]; do sleep 1; done
fi
RESULT=fail